"use strict";
const command_1 = require("@oclif/command");
const cli_ux_1 = require("cli-ux");
const fs_1 = require("fs");
const path_1 = require("path");
const child_process_1 = require("child_process");
const create_node_1 = require("./create-node");
const CWD = process.cwd();
class CreateTsProject extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(CreateTsProject);
        let projectName = args.projectName || flags.projectName;
        if (!projectName) {
            projectName = await cli_ux_1.default.prompt('Enter project name');
        }
        let { projectType = await cli_ux_1.default.prompt('Enter type of project ("node" or "react")'), email = await cli_ux_1.default.prompt('Enter email address'), authorName = await cli_ux_1.default.prompt('Enter author name'), githubUser = await cli_ux_1.default.prompt('Enter github username'), init, } = flags;
        const createDirPath = path_1.resolve(CWD, projectName);
        if (!init) {
            if (fs_1.existsSync(createDirPath)) {
                throw new Error(`"${createDirPath}" already exist`);
            }
            fs_1.mkdirSync(createDirPath);
        }
        const projectRoot = init ? CWD : createDirPath;
        switch (projectType) {
            case 'node': {
                await create_node_1.createNode({
                    projectName,
                    projectType,
                    email,
                    authorName,
                    githubUser,
                    projectRoot,
                });
                break;
            }
            case 'react': {
                throw new Error('Not implemented');
            }
            default: {
                break;
            }
        }
        process.chdir(projectRoot);
        child_process_1.execSync('yarn install', { stdio: 'inherit', shell: '/bin/bash' });
        process.chdir('..');
    }
}
CreateTsProject.description = 'describe the command here';
CreateTsProject.flags = {
    version: command_1.flags.version({ char: 'v' }),
    help: command_1.flags.help({ char: 'h' }),
    projectName: command_1.flags.string({ char: 'n', description: 'project name' }),
    projectType: command_1.flags.string({ char: 't', description: 'project type ( React/node )' }),
    authorName: command_1.flags.string({ char: 'a', description: 'author name' }),
    email: command_1.flags.string({ char: 'e', description: 'email' }),
    githubUser: command_1.flags.string({ char: 'g', description: 'github user name' }),
    init: command_1.flags.boolean({ char: 'i', description: 'init project in current working directory' })
};
CreateTsProject.args = [{ name: 'projectName' }];
module.exports = CreateTsProject;
